@@ -6,6 +6,4 @@ from .lowest_rank_intersection import lowest_rank_intersection
 from .downstream import downstream
 from .synonyms import synonyms
 from .children import children
-from .upstream import upstream
-import warnings
-warnings.filterwarnings("ignore")
+from .upstream import upstream
\ No newline at end of file
