@@ -1,4 +1,12 @@
-from .services import createIndex,crushIndexInput,writeApiResultsToIndex,ensureUniqueInIndex,findDownstreamChildren,tagInputWithTaxaLevel,findDownstreamChildren,taxa_ordering
+from .services import createIndex, \
+                      crushIndexInput, \
+                      writeApiResultsToIndex, \
+                      ensureUniqueInIndex, \
+                      findDownstreamChildren, \
+                      tagInputWithTaxaLevel, \
+                      findDownstreamChildren, \
+                      taxa_ordering 
+                      
 from collections import defaultdict
 
 def children(names):
