@@ -1,13 +1,16 @@
-from .services import createIndex,crushIndexInput,writeApiResultsToIndex,ensureUniqueInIndex,findDownstreamChildren,tagInputWithTaxaLevel
+from .services import createIndex,\
+                      crushIndexInput,\
+                      writeApiResultsToIndex,\
+                      ensureUniqueInIndex,\
+                      findDownstreamChildren,\
+                      tagInputWithTaxaLevel
 
 def downstream(names,rank):
     index = createIndex(names)
     taggedInput = tagInputWithTaxaLevel([x[0] for x in crushIndexInput(index)])
     writeApiResultsToIndex(index,taggedInput) 
     nameAndRankTuple = crushIndexInput(index)
-    namesOnly = first(nameAndRankTuple)
-    rankTuples = second(nameAndRankTuple)
-    results = list(zip(namesOnly,[x[1] for x in findDownstreamChildren(rankTuples,rank)]))
+    results = list(findDownstreamChildren(nameAndRankTuple,rank))
     writeApiResultsToIndex(index,results)
     return index
     
