@@ -4,9 +4,10 @@ def constructUrls(name):
 
 def processIndividualResult(nameAndResTuple):
     name,res = nameAndResTuple
-    errorCode = (name,-1)
+    errorCode = (name,'-1')
     if 'scientificNames' not in res: return errorCode
     if res['scientificNames'] is None: return errorCode
+    if res['scientificNames'][0] is None: return errorCode
     if len(res['scientificNames']) == 0: return errorCode
 
     for item in res['scientificNames']:
