@@ -10,7 +10,7 @@ def tagInputWithTaxaLevel(names):
     except Exception as e:
         print("Caught fatal exception in taxonomic indexer")
         print(str(e))
-        return list(map(lambda x: ('',x),names))
+        return list(map(lambda x: (x,('',x)),names))
 
 
     
