@@ -8,10 +8,15 @@ from .services import commonToScientific, \
                       ensureUniqueInIndex, \
                       profile_taxonomy, \
                       highest_count_wins_multi_cat, \
-                      findDownstreamChildren
+                      findDownstreamChildren \
 
-def to_scientific(names):
+from .speciesValidation import sanityCheckOutput
+
+def to_scientific(names,sanityCheck=False):
     index = createIndex(names)
     results = commonToScientific(names)
     writeApiResultsToIndex(index,results)
+    if sanityCheck: 
+        index = sanityCheckOutput(index)
+    ensureUniqueInIndex(index)
     return index
